Package: SpotSweeper
Title: Spatially-aware quality control for spatial transcriptomics
Version: 1.9.0
Date: 2025-10-14
Authors@R: c(
    person("Michael", "Totty", ,"mictott@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-9292-8556")),
    person("Stephanie", "Hicks", ,email = "shicks19@jhu.edu", role = c("aut"),
           comment = c(ORCID = "0000-0002-7858-0231")),
    person("Boyi", "Guo", ,email = "boyi.guo.work@gmail.com", role = c("aut"),
           comment = c(ORCID = "0000-0003-2950-2349")))
Description: Spatially-aware quality control (QC) software for both spot-level 
    and artifact-level QC in spot-based spatial transcripomics, such as 10x 
    Visium. These methods calculate local (nearest-neighbors) mean and variance 
    of standard QC metrics (library size, unique genes, and mitochondrial 
    percentage) to identify outliers spot and large technical artifacts.
License: MIT + file LICENSE
URL: https://github.com/MicTott/SpotSweeper
BugReports: https://support.bioconductor.org/tag/SpotSweeper
biocViews: Software, Spatial, Transcriptomics, QualityControl,
        GeneExpression,
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.1
Depends: R (>= 4.4.0)
Imports: SpatialExperiment, SummarizedExperiment, BiocNeighbors,
        SingleCellExperiment, stats, escheR, MASS, ggplot2, spatialEco,
        grDevices, BiocParallel
Suggests: knitr, BiocStyle, rmarkdown, scuttle, STexampleData, ggpubr,
        testthat (>= 3.0.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
LazyData: False
News: NEWS.md
git_url: https://git.bioconductor.org/packages/SpotSweeper
git_branch: devel
git_last_commit: 5c89af8
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 23:35:06 UTC; biocbuild
Author: Michael Totty [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-9292-8556>),
  Stephanie Hicks [aut] (ORCID: <https://orcid.org/0000-0002-7858-0231>),
  Boyi Guo [aut] (ORCID: <https://orcid.org/0000-0003-2950-2349>)
Maintainer: Michael Totty <mictott@gmail.com>
Built: R 4.6.0; ; 2026-05-19 05:11:03 UTC; unix
