# Generated by roxygen2: do not edit by hand

export(findArtifacts)
export(flagVisiumOutliers)
export(localOutliers)
export(localVariance)
export(plotQCmetrics)
export(plotQCpdf)
import(SingleCellExperiment)
import(SpatialExperiment)
importFrom(BiocNeighbors,findKNN)
importFrom(BiocParallel,MulticoreParam)
importFrom(MASS,rlm)
importFrom(SummarizedExperiment,colData)
importFrom(escheR,add_fill)
importFrom(escheR,add_ground)
importFrom(escheR,make_escheR)
importFrom(ggplot2,coord_fixed)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_gradient2)
importFrom(ggplot2,scale_y_reverse)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(spatialEco,outliers)
importFrom(stats,kmeans)
importFrom(stats,prcomp)
importFrom(stats,resid)
importFrom(stats,var)
importFrom(utils,data)
